# Installation

At the command line:

    $ pip install striplog

Or, if you use Conda environments:

    $ conda create -n striplog python=3.9
    $ conda activate striplog
    $ pip install striplog

For developers, there are also options for installing `tests`, `docs` and `dev` dependencies.

If you want to help develop striplog, please read [Development](development.md).
